@@ -62,16 +62,25 @@ void DummyBackend::populate(const QString& n)
     const int start = m_resources.count();
     for(int i=start; i<start+m_startElements; i++) {
         const QString name = n+QLatin1Char(' ')+QString::number(i);
-        DummyResource* res = new DummyResource(name, false, this);
+        DummyResource* res = new DummyResource(name, AbstractResource::Application, this);
         res->setSize(100+(m_startElements-i));
         res->setState(AbstractResource::State(1+(i%3)));
         m_resources.insert(name.toLower(), res);
         connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
     }
 
+    for(int i=start; i<start+m_startElements; i++) {
+        const QString name = QStringLiteral("addon")+QString::number(i);
+        DummyResource* res = new DummyResource(name, AbstractResource::Addon, this);
+        res->setState(AbstractResource::State(1+(i%3)));
+        res->setSize(300+(m_startElements-i));
+        m_resources.insert(name, res);
+        connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
+    }
+
     for(int i=start; i<start+m_startElements; i++) {
         const QString name = QStringLiteral("techie")+QString::number(i);
-        DummyResource* res = new DummyResource(name, true, this);
+        DummyResource* res = new DummyResource(name, AbstractResource::Technical, this);
         res->setState(AbstractResource::State(1+(i%3)));
         res->setSize(300+(m_startElements-i));
         m_resources.insert(name, res);
@@ -99,7 +108,7 @@ ResultsStream* DummyBackend::search(const AbstractResourcesBackend::Filters& fil
     if (!filter.resourceUrl.isEmpty())
         return findResourceByPackageName(filter.resourceUrl);
     else foreach(AbstractResource* r, m_resources) {
-        if (r->isTechnical() && filter.state != AbstractResource::Upgradeable) {
+        if (r->type() == AbstractResource::Technical && filter.state != AbstractResource::Upgradeable) {
             continue;
         }
 
@@ -114,6 +123,15 @@ ResultsStream* DummyBackend::search(const AbstractResourcesBackend::Filters& fil
 
 ResultsStream * DummyBackend::findResourceByPackageName(const QUrl& search)
 {
+    if(search.isLocalFile()) {
+        DummyResource* res = new DummyResource(search.fileName(), AbstractResource::Technical, this);
+        res->setSize(666);
+        res->setState(AbstractResource::None);
+        m_resources.insert(res->packageName(), res);
+        connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
+        return new ResultsStream(QStringLiteral("DummyStream-local"), { res });
+    }
+
     auto res = search.scheme() == QLatin1String("dummy") ? m_resources.value(search.host().replace(QLatin1Char('.'), QLatin1Char(' '))) : nullptr;
     if (!res) {
         return new ResultsStream(QStringLiteral("DummyStream"), {});
@@ -156,16 +174,6 @@ void DummyBackend::checkForUpdates()
     qDebug() << "DummyBackend::checkForUpdates";
 }
 
-AbstractResource * DummyBackend::resourceForFile(const QUrl& path)
-{
-    DummyResource* res = new DummyResource(path.fileName(), true, this);
-    res->setSize(666);
-    res->setState(AbstractResource::None);
-    m_resources.insert(res->packageName(), res);
-    connect(res, &DummyResource::stateChanged, this, &DummyBackend::updatesCountChanged);
-    return res;
-}
-
 QString DummyBackend::displayName() const
 {
     return QStringLiteral("Dummy");
