@@ -39,13 +39,6 @@ public:
         : QStandardItemModel(backend)
         , m_backend(backend) {}
 
-    QHash<int, QByteArray> roleNames() const override
-    {
-        auto roles = QStandardItemModel::roleNames();
-        roles[Qt::CheckStateRole] = "checked";
-        return roles;
-    }
-
     bool setData(const QModelIndex & index, const QVariant & value, int role) override {
         auto item = itemFromIndex(index);
         if (!item)
@@ -126,17 +119,16 @@ void PackageKitSourcesBackend::addRepositoryDetails(const QString &id, const QSt
     QStandardItem* item = findItemForId(id);
 
     if (!item) {
-        QString desc = description;
+        item = new QStandardItem(description);
         if (PackageKit::Daemon::backendName() == QLatin1String("aptcc")) {
             QRegularExpression exp(QStringLiteral("^/etc/apt/sources.list.d/(.+?).list:.*"));
 
             auto matchIt = exp.globalMatch(id);
             if (matchIt.hasNext()) {
                 auto match = matchIt.next();
-                desc += QStringLiteral(" - ") + match.captured(1);
+                item->setData(match.captured(1), Qt::ToolTipRole);
             }
         }
-        item = new QStandardItem(desc);
         add = true;
     }
     item->setData(id, IdRole);
